@@ -1,7 +1,8 @@
 import glob
 import json
 import os
-import subprocess
+import re
+from subprocess import check_output
 from abc import ABC, abstractmethod
 
 
@@ -27,21 +28,16 @@ class FilDataPrep(E2EDataPrep):
         self.bin = bin
         self.root = None
 
-    @staticmethod
-    def _get_files(data_dir):
-        for file in glob.glob(data_dir + "**/*r", recursive=True):
-            if os.path.isfile(file):
-                yield file
-
     def prepare_data(self, data_dir, size, output, metadata):
-        files = self._get_files(data_dir)
-        for file in files:
-            generate_cmd = [self.bin, 'fil-data-prep', '--size', str(size), '--output', output, '--metadata', metadata]
-            with open(file, 'r') as inp:
-                pipe = subprocess.Popen(generate_cmd, stdin=inp, stdout=subprocess.DEVNULL, stderr=subprocess.PIPE)
+        generate_cmd = [self.bin, 'dp', '--size', str(size), '--output', output, '--metadata', metadata, data_dir]
+        out = check_output(generate_cmd)
+        out = out.decode().strip()
 
-        _, std_err = pipe.communicate()
-        self.root = json.loads(std_err)['cid']
+        rcid_re = re.compile(r'root cid = (\S+)')
+
+        rcid = rcid_re.findall(out)
+
+        self.root = rcid[0]
 
     def get_root_cid(self):
         return self.root
